<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Form Recipients /////////////////////////
// Buttons:
define('FORM_RECIPIENTS_HEADING', "Edit Form Mottagare");
define('FORM_RECIPIENTS_EDIT_FORM_RECIPIENTS_BTN', "Edit Form Mottagare");
// Console Text:
define('FORM_RECIPIENTS_FORM_PAGE', "Form Page");
define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Du kan ställa in mer än en mottagare genom att separera e-post med kommatecken.");
// Popup Messages:
define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Sparar mottagaren ...");
define('VIEW_FORM_TABLES_HEADING', "Visa formulärtabeller");
define('VIEW_FORM_TABLES_BTN', "Visa formulärtabeller");
define('VIEW_FORM_TABLES_SELECT_TABLE', "Välj ett tabeller att visa");
define('VIEW_FORM_TABLES_FILTER_READ', "Filtrera läsmeddelanden");
?>